@@ -1,5 +1,5 @@
 package Beam::Runner::Command::list;
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 # ABSTRACT: List the available containers and services
 
 #pod =head1 SYNOPSIS
@@ -142,9 +142,6 @@ sub _list_service {
     # If it doesn't look like a service, we don't care
     return unless $wire->is_meta( $svc, 1 );
 
-    # Service hashes should be loaded and printed
-    my %meta = $wire->get_meta_names;
-
     # Services that are just references to other services should still
     # be available under their referenced name
     my %svc = %{ $wire->normalize_config( $svc ) };
@@ -212,7 +209,7 @@ Beam::Runner::Command::list - List the available containers and services
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
